#!/bin/sh
#
# $Id: makedocs.sh,v 1.4 2001/01/14 01:26:36 zyrnix Exp $
#
# This will create different formats for the SAStk documentation if you have
# the appropriate programs.
#
################################################################################
# SAStk Texinfo makedocs.sh
# Copyright (C) 2000 Doug Hogan
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
################################################################################


# Set this to your location of which.
WHICH=/usr/bin/which

# This tries to find the first argument given to it.  If the 'which' command
# finds it, then the rest of the commands are executed.
# Example:  find_it echo echo "hi"
# That would output 'hi'.
find_it() {
   if [ ! -z "$(${WHICH} $1 2>/dev/null | grep "$1: Command not found")" ]; then
        echo "Couldn't find $1"
   else
        shift
        $*
   fi
}

if [ ! -d info ]; then
    mkdir info
fi 
cd info
find_it makeinfo makeinfo ../sastk.texi
cd ..
if [ ! -d html ]; then 
    mkdir html
fi 
cd html
cp ../sastk_logo.jpg ../sastk_logo_l.jpg .
find_it makeinfo makeinfo --html ../sastk.texi
cd ..

# Most everyone uses the ancient 1.56k version of texi2html.  The updated
# version (1.64) has _many_ new options and is completely configurable from a
# texi2html.init file.
#
# If you do have the modern (July 2000) version of texi2html, you can use this
# version if you edit your *.init file in addition.  I'll probably need to CVS
# my *.init file so everyone is in sync if they do decide to join in with 1.64.
#
# Where to get the new texi2html:
# http://www.mathematik.uni-kl.de/~obachman/Texi2html/Distrib/texi2html-1.64.tar.gz


if [ "$($(${WHICH} texi2html) --version)" = "1.64" ]; then

    if [ ! -d html_multiple ]; then
        mkdir html_multiple
    fi 
    cp sastk_logo.jpg sastk_logo_l.jpg html_multiple/
    if [ ! -d html_single ]; then
        mkdir html_single
    fi 
    cp sastk_logo.jpg sastk_logo_l.jpg html_single/

    # Multiple HTML files

    find_it texi2html texi2html -init_file /opt/local/etc/texi2html.init -split chapter -frames -top_file index.html -number -section_navigation -subdir html_multiple sastk.texi

    # Single HTML 

    find_it texi2html texi2html -init_file /opt/local/etc/texi2html.init -split none -number -section_navigation -subdir html_single sastk.texi

else
    if [ ! -d html_single ]; then
        mkdir html_single
    fi
    cd html_single
    cp ../sastk_logo.jpg ../sastk_logo_l.jpg .
    cp ../sastk_logo.jpg ../sastk_logo_l.jpg .
    find_it texi2html texi2html ../sastk.texi
    cd ..
fi

if [ ! -d dvi ]; then
   mkdir dvi
fi
cd dvi
find_it texi2dvi texi2dvi ../sastk.texi
for file in $(ls -1 | grep -v '\.dvi$'); do
   rm $file
done
cd ..
if [ ! -d pdf ]; then
   mkdir pdf
fi
cd pdf
find_it texi2pdf texi2pdf ../sastk.texi
for file in $(ls -1 | grep -v '\.pdf$'); do
   rm $file
done
cd ..
if [ ! -d ps ]; then
   mkdir ps
fi
cd ps
find_it dvips dvips -o sastk.ps ../dvi/sastk.dvi
cd ..

# Get rid of those annoying texi2html output lines
# Create an HTML document that's all in one file, rather than a TOC and the rest
# Not needed if you use a recent version of texi2html
if [ -d html ]; then
    cd html
    if [ -f sastk.html ]; then
        cat sastk.html >> sastk_toc.html
        sed -e 's/sastk.html//g' -e 's/.*This document was generated on.*//g' \
        -e 's/.*texi2html.*//g' sastk_toc.html > sastk_one_single.html
    fi
fi
