#!/bin/sh
# $Id: install.sh,v 1.31 2002/01/01 16:26:41 zyrnix Exp $

#############################################
#
# SAStk install Script
#
# For Slackware Linux 8.0
#
#############################################
# SAStk 0.1.3.0
# Copyright (C) 2000 John Jenkins, Doug Hogan, Jeffrey Denton
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###########################

# Sanity check
if [ ! -d /etc/rc.d ]; then
    /bin/mkdir -m 755 -p /etc/rc.d
fi

if [ -d /root/.sastk_tmp ]; then
    /bin/rm -rf /root/.sastk_tmp
fi
/bin/mkdir -m 700 -p /root/.sastk_tmp

# Setup signal handler
handle_sigint() {
    /bin/stty intr ""
    /bin/echo -n "                 WARNING : ctrl+c pressed!"
    /bin/echo -ne " Killing SAStk                         "
    /bin/echo
    # Remove any temporary files and aliases
    if [ -d /root/.sastk_tmp ]; then
        /bin/rm -r /root/.sastk_tmp   
    fi
    /bin/stty intr ^C
    exit 1
}

trap handle_sigint 2

###############
#Check for root
###############

ver="0.1.3.0"

if [ ! "${UID}" = "0" ]; then
    /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Error" --msgbox \
"You must be root to run the SAStk script!!\
\nPlease log in or \"su -\" to root." 7 50
    exit
fi

/bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "SAStk Install" --msgbox \
"Welcome to the SAStk installation script\
\n\nChecking System \n\
     Please Wait" 7 50

#################
# Check version #
#################

if [ ! -f "/etc/slackware-version" ]; then
    /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Error!" --msgbox \
"/etc/slackware-version does NOT exist!\n\n\
This does not appear to be Slackware!" 7 50
    exit
fi

version=$(/usr/bin/cut -f1 -d' '  /etc/slackware-version)

if [ -z "$(echo ${version} | grep '8.0')" ]; then
    /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Error!" --msgbox \
"SAStk installation script ${ver} \n\
does not support Slackware ${version} at this time.\n\n\
Bug the developers for support " 10 60
    exit
fi

##########################################
# Check if SAStk is installed already 
##########################################

if [ -f /etc/rc.d/rc.conf ]; then
    /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Error!" --msgbox \
"SAStk is already installed!\n\
Please run ./sastk.sh to configure your system\n\
Or ./sastk_undo.sh to uninstall SAStk" 8 60
    exit
fi 

##########################################
# Check if SAStk has been installed before
##########################################

if [ "${1}" != "-force" ];then
    if [ -d /var/log/sastk ]; then
/bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Error!" --msgbox \
"We detect that you still have the logs and backup files\n\
from a previous SAStk installation\n\
If you have uninstalled SAStk you can rm -rf /var/log/sastk\n\
to remove the previous installs backup and log files\n\
or you may wish to rename the /var/log/sastk directory\n\
If you wish to append the logs from this install to\n\
the existing logs then you may run $0 -force\n\
to overide this check" 12 70
        exit
    fi
fi

###############################
# Checking for single user mode
###############################

if [ "$(/sbin/runlevel | /usr/bin/awk '{print $2}')" != "1" ]; then
    quit=n
    while [ "${quit}" = "n" ]; do
        /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "SAStk ${ver}" --menu \
"This script should be run in single user mode\n\
If you are in single user mode this is a bug, press (1)\n\
If you are not already in single user mode, press (2)" 13 60 3 \
1	"Continue in current mode" \
2	"Enter Single user mode" \
Q	"Quit this script" \
2> /root/.sastk_tmp/answer

menuitem=`cat /root/.sastk_tmp/answer`
opt=$?

case $menuitem in
    1)     quit="y"
           ;;
    2)     if [ -f /root/.bash_login ]; then
              /bin/cp /root/.bash_login /root/.bash_login.bak
           fi
           CDIR=$(/bin/pwd)
           /usr/bin/cat > /root/.bash_login <<EOF
#!/bin/sh
if [ "\$(/sbin/runlevel | awk '{print \$2}')" = "1" ]; then
    quit="n"
    while [ "\${quit}" = "n" ]; do
cat << !
********************************************************************************
*                     SAStk installation script version ${ver}
********************************************************************************

This is part of the SAStk Installation
You should now be in Single user mode.
please choose an option from below.


1) Every thing seems okay.. continue with the installation
2) What the.... Stop this madness and don't let it happen again
Q) Just quit this I'll handle the rest myself

!
    /bin/echo -ne "Choose an Option: .\b"
    read choice
    case \${choice} in
        1)       quit="y"
                 cd ${CDIR}
                 ./install.sh
                 ;;
        2)       if [ -f /root/.bash_login.bak ]; then
                     mv /root/.bash_login.bak /root/.bash_login
                 elif [ -f /root/.bash_login ]; then
                     rm /root/.bash_login
                 fi
                 quit="y"
                 ;;
      Q|q)       quit="y"
                 ;;
        *)       /bin/echo -ne "Invalid choice!! \a\a"
                 ;;
     esac
   done
fi
EOF
                    /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Initializing" --msgbox \
"\n             Switching to S Mode.\n\n\
    You will need to log back in as root.\n\n\
  The install should continue automatically" 10 50 
                   /sbin/telinit 1; exit 0
                   ;;
        Q|q)       exit 1
                   ;;
          *)       /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Initializing" --msgbox \
"\nInvalid choice!! \n" 6 40
                   ;;
     esac
   done
fi

OLDPATH="${PATH}"
PATH=/sbin:/usr/sbin:/bin:/usr/bin
umask 077

##########################################
# Sanity check for directories and files #
##########################################

[ ! -d "/var/log/sastk" ] && /bin/mkdir -m 0700 "/var/log/sastk"
[ ! -d "/root/.sastk_tmp" ] && /bin/mkdir -m 0700 "/root/.sastk_tmp"
[ ! -d "/var/log/sastk/backup" ] && /bin/mkdir -m 0700 "/var/log/sastk/backup"
[ ! -f "/var/log/sastk/sastk_install.log" ] && /bin/touch "/var/log/sastk/sastk_install.log"
[ ! -f "/var/log/sastk/sastk_err.log" ] &&  /bin/touch "/var/log/sastk/sastk_err.log"

/bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "SAStk logging" --msgbox \
"\nSetting up logging\
\nInstall log is /var/log/sastk/sastk_install.log \
\nBackups are under /var/log/sastk/backup \n" 8 60

###########################
# Create backup directories
###########################

for dir in \
/etc \
/etc/rc.d \
/root \
/var \
/var/X11R6 \
/var/X11R6/lib \
/var/X11R6/lib/xdm \
/usr \
/sbin \
/usr/X11R6 \
/usr/X11R6/bin ;do
     [ ! -d /var/log/sastk/backup${dir} ] && /bin/mkdir "/var/log/sastk/backup${dir}"
done

# Set sendmail directory
if [ ! -z "$(echo ${version} | grep '8.0')" ]; then
    SENDMAILDIR="/etc/mail"
else
    /bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Error!" --msgbox \
"\nPlease report this bug!  Invalid version!\n" 6 60
    exit
fi

[ ! -d "/var/log/sastk/backup/etc/mail" ] && /bin/mkdir -m 0700 "/var/log/sastk/backup/etc/mail"

CURRENT_DATE=$(date)
SASTK_ID='$Id: install.sh,v 1.31 2002/01/01 16:26:41 zyrnix Exp $'

##################
# Start the work #
##################

/bin/echo "SAStk was installed on $CURRENT_DATE." >> /var/log/sastk/sastk_install.log
/bin/echo ${SASTK_ID} >> /var/log/sastk/sastk_install.log

/bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Initializing" --msgbox \
"\nSystem checks out okay\
\npress enter to begin installing the files.\n" 8 60

# Back up and install sasrc
# Don't backup and install CVS tree maintenance files.
for i in $(/usr/bin/find etc/ -type f | /usr/bin/grep -v CVS); do
    file=${i}
    newfile="/${i}"
        if [ -f "${newfile}" ]; then
        /bin/cp -p "${newfile}" "/var/log/sastk/backup${newfile}" 1>> /var/log/sastk/sastk_install.log 2>> /var/log/sastk/sastk_err.log
        fi    
    /bin/cp -vpf "${file}" "${newfile}"  1>> /var/log/sastk/sastk_install.log 2>> /var/log/sastk/sastk_err.log
done

# Backup and install netconfig.color
if [ ! -f "/var/log/sastk/backup/sbin/netconfig.color" ]; then
    /bin/cp -pf "/sbin/netconfig.color" "/var/log/sastk/backup/sbin/netconfig.color" 2>> /var/log/sastk/sastk_err.log
fi
/bin/cp -pf "sbin/netconfig.color" "/sbin/netconfig.color" 2>> /var/log/sastk/sastk_err.log

# Create /etc/rc.d/rc.0 symlink to /etc/rc.d/rc.6
if [ ! -L /etc/rc.d/rc.0 ]; then
    /bin/ln -s /etc/rc.d/rc.6 /etc/rc.d/rc.0
fi

# Set permissions for rc.d and netconfig.color
/bin/chmod 0700 /etc/rc.d/rc.* "/sbin/netconfig.color" 2>> /var/log/sastk/sastk_err.log
/bin/chown root.root /etc/rc.d/rc.* "/sbin/netconfig.color" 2>> /var/log/sastk/sastk_err.log

# Make backups of all files to be modified.
for x in $(/usr/bin/cat filelist);do
    if [ -f ${x} ]; then
        if [ ! -f "/var/log/sastk/backup${x}" ]; then
        /bin/cp -vp "${x}" "/var/log/sastk/backup${x}" 1>> /var/log/sastk/sastk_install.log 2>> /var/log/sastk/sastk_err.log
        fi
        /bin/cp -p "${x}" "/var/log/sastk/backup${x}.sastk" 2>> /var/log/sastk/sastk_err.log
    fi
done

# Create md5sums for files that will be modified
for m in $(/usr/bin/cat filelist);do
    if [ -f ${m} ]; then
        /usr/bin/md5sum "${m}" 1>> "/var/log/sastk/filelist.md5" 2>> /var/log/sastk/sastk_err.log
    fi
done

# Install sastk.info file
if [ ! -f /usr/local/info/sastk.info ]; then
    /bin/cp "../docs/sastk.info" "/usr/local/info/" 2>> /var/log/sastk/sastk_err.log
fi
    /usr/bin/install-info "../docs/sastk.info" "/usr/local/info/dir" 2>> /var/log/sastk/sastk_err.log

# Finishing up
/bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Install Complete" --msgbox \
"\nSlackware Administrator's Security Toolkit installation\
\nhas completed successfully" 8 70

/bin/echo "Installation of $SASTK_ID" >> /var/log/sastk/sastk_install.log
/bin/echo "SAStk ${ver} completed on $CURRENT_DATE" >> /var/log/sastk/sastk_install.log

# Take care of .bash_login
if [ -f /root/.bash_login.bak ]; then
    /bin/mv /root/.bash_login.bak /root/.bash_login
elif [ -f /root/.bash_login ]; then
    /bin/rm /root/.bash_login 2>> /var/log/sastk/sastk_err.log
fi

# unset anything we've exported
for i in errlog logfile BKUP LOG RC SENDMAILDIR TMPDIR version ; do
    unset $i
done

export PATH="${OLDPATH}"

/bin/dialog --backtitle "Slackware Security ToolKit [ http://sourceforge.net/projects/sastk ]" --title "Begin Configuration" --msgbox \
"\npress enter to begin the configuration\n" 6 60

# Start the installer program
if [ -x ./sastk.sh ]; then 
    ./sastk.sh
else
    echo "Error, file ./sastk.sh not executable!"
fi
