#!/bin/sh
#
# $Id: security-control.sh,v 1.8 2002/01/01 18:23:25 dentonj Exp $
#
######################################
#
# Seccheck for Slackware Linux
#
# The program was modified for SAStk by Jeffrey Denton <dentonj@sastk.org>.  
# It was originally written by Marc Heuse <marc@suse.de> for SuSE.  
#
######################################
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###########################

####
#
# Seccheck master control security mechanism for the daily/weekly/monthly
# security checks.
#
####
VERSION="v0.2"

function syntax () {
    /bin/echo "Syntax: $0 "'daily|weekly|monthly'
    exit 1
}

function disclaimer () {
    /bin/echo
    /bin/echo "DISCLAIMER"
    /bin/echo
    /bin/echo "Please note that these security checks are neither complete nor reliable."
    /bin/echo "Any attacker with proper experience and root access to your system can"
    /bin/echo "deceive *any* security check!"
    /bin/echo
}

test -z "$1" && syntax

test -x "/usr/bin/sendmail" && MAILER="/usr/bin/sendmail"
test -z "$MAILER" && test -x "/bin/mailx" && MAILER="/bin/mailx"
test -z "$MAILER" && echo "Can not find a suitable mailer!"
test -z "$MAILER" && exit 1
export MAILER

umask 077
PATH="/sbin:/usr/sbin:/bin:/usr/bin"
SECCHK_USER="root"
SEC_BIN="/usr/local/sbin/seccheck"
SEC_DATA="$SEC_VAR/data"
SEC_VAR="/var/log/sastk/seccheck"
OUT1="$SEC_VAR/security-report-daily.new"
OLD1="$SEC_VAR/security-report-daily"
OUT2="$SEC_VAR/security-report-weekly.new"
OLD2="$SEC_VAR/security-report-weekly"
OLD3="$SEC_VAR/security-report-monthly"


if [ ! -d "$SEC_VAR" ]; then
    /bin/mkdir "$SEC_VAR" || exit 1
fi
if [ ! -d "$SEC_DATA" ]; then
    /bin/mkdir "$SEC_DATA" || exit 1
fi
for i in "$OLD1" "$OLD2" "$OLD3" ; do
    if [ "$i" != "" ]; then
        if [ ! -e "$i" ]; then
   	    touch "$i"
        fi
    fi
done

# Daily
test "$1" = "daily" && (
 /bin/sh "$SEC_BIN/security-daily.sh" 1> "$OUT1"
 /usr/bin/diff -q -w "$OLD1" "$OUT1" 1> /dev/null || (
    {
      /bin/echo "To: $SECCHK_USER"
      /bin/echo -e "Subject: Local Daily Security for `hostname`: Changes\n"
      /bin/echo "Slackware daily security check $VERSION by SAStk"
      /bin/echo "This is an automated mail by the seccheck tool. If you want to disable this"
      /bin/echo "service, just type \"crontab -e\" as root and comment the appropriate lines."
      disclaimer
      /bin/echo -e "Changes in your daily security configuration of `hostname`:\n"
      /usr/bin/diff -u -w "$OLD1" "$OUT1" | sed 's/^@@.*/\
* Changes (+: new entries, -: removed entries):\
	/' | /usr/bin/egrep '^[+*-]|^$' | /usr/bin/sed 's/^+++/NEW:/' | /usr/bin/sed 's/^---/OLD:/' | /usr/bin/sed 's/^[+-]/& /'
    } | $MAILER "$SECCHK_USER"
    /bin/mv "$OUT1" "$OLD1"
 )
 /bin/rm -f "$OUT1"
)

# Weekly
test "$1" = "weekly" && (
 /bin/sh "$SEC_BIN/security-weekly.sh" 1> "$OUT2"
 if [ -s "$OUT2" ]; then
    {
      /bin/echo "To: $SECCHK_USER"
      /bin/echo -e "Subject: Local Weekly Security for `hostname`: Changes\n"
      /bin/echo "Slackware weekly security check $VERSION by SAStk"
      /bin/echo "This is an automated mail by the seccheck tool. If you want to disable this"
      /bin/echo "service, just type \"crontab -e\" as root and comment the appropriate lines."
      disclaimer
      /bin/echo -e "Changes in your weekly security configuration of `hostname`:\n"
      /usr/bin/cat "$OUT2"
    } | $MAILER "$SECCHK_USER"
    /bin/mv "$OUT2" "$OLD2"
 fi
 /bin/rm -f "$OUT2"
)

# Monthly
test "$1" = "monthly" && (
 test -s "$OLD1" || /bin/sh "$SEC_BIN/security-daily.sh" 1> "$OLD1"
 test -e "$SEC_DATA/devices" || /bin/sh "$SEC_BIN/security-weekly.sh" 1> "$OLD2"
 {
      /bin/echo "To: $SECCHK_USER"
      /bin/echo -e "Subject: Local Monthly Security for `hostname`: Complete\n"
      /bin/echo "Slackware monthly security check $VERSION by SAStk"
      /bin/echo "This is an automated mail by the seccheck tool. If you want to disable this"
      /bin/echo "service, just type \"crontab -e\" as root and comment the appropriate lines."
      disclaimer
      /bin/echo -e "Complete monthly listing of `hostname`:\n"
      /bin/sh "$SEC_BIN/security-monthly.sh"
 } | /usr/bin/tee "$OLD3" | $MAILER "$SECCHK_USER"
)

exit 0
