#!/bin/sh
#
# $Id: security-daily.sh,v 1.7 2002/01/01 18:24:10 dentonj Exp $
#
######################################
#
# Seccheck for Slackware Linux
#
# The program was modified for SAStk by Jeffrey Denton <dentonj@sastk.org>.  
# It was originally written by Marc Heuse <marc@suse.de> for SuSE.  
#
######################################

####
#
# Slackware daily security checks 
#
####

umask 077
PATH=/sbin:/usr/sbin:/bin:/usr/bin
TMPDIR=`/usr/bin/mktemp -d /root/.security.XXXXXX 2> /dev/null` || {
    TMPDIR="/root/.security-daily.sh.$$"
    /bin/mkdir "$TMPDIR" || exit 1
}
LOG="$TMPDIR/security.log"
ERR="$TMPDIR/security.err"
OUT="$TMPDIR/security.out"
TMP1="$TMPDIR/security.tmp1"
TMP2="$TMPDIR/security.tmp2"

trap 'rm -rf $TMPDIR; exit 1' 0 1 2 3 13 15

#
# /etc/passwd check
#
PW="/etc/passwd"
/usr/bin/awk -F: '{
        if ($0 ~ /^[ 	]*$/) {
                printf("Line %d is a blank line.\n", NR);
                next;
        }
        if (NF != 7)
                printf("Line %d has the wrong number of fields.\n", NR);
        if ($1 ~ /^[+-]$/)
                next;
        if ($1 == "")
                printf("Line %d has an empty login field.\n", NR);
        else if ($1 !~ /^[A-Za-z0-9][A-Za-z0-9_\.-]*$/)
                printf("Login %s has non-alphanumeric characters.\n", $1);
        if (length($1) > 8)
                printf("Login %s has more than 8 characters.\n", $1);
        if ($2 == "")
                printf("Login %s has no password.\n", $1);
        else if ($2 !~ /^[x*!]+$/)
		printf("Login %s has a real password (it is not shadowed).\n", $1);

####
# This section was originally commented by Marc
#
#if ($2 != "" && length($2) != 13 && ($10 ~ /.*sh$/ || $10 == "") &&
#   ($2 !~ /^\$[0-9a-f]+\$/)) {
#       if (system("test -d "$9" -a ! -r "$9"") == 0)
#          printf("Login %s if off but still has valid shell and home directory is unreadable\n\t by root; cannot check for existance of alternate access files.\n", $1);
#       else if (system("for file in .ssh .rhosts .shosts .klogin;
#               do if test -e "$9"/$file; then if ((ls -ld "$9"/$file | cut -b 2-10 | grep -q r) && (test ! -O "$9"/$file)) ; then exit 1; fi; fi; done"))
#                  printf("Login %s is off but still has a valid shell and alternate access files in\n\t home directory are still readable.\n",$1);
#}
####

        if ($3 == 0 && $1 != "root")
                printf("Login %s has a user id of 0.\n", $1);
        if ($3 == 1 && $1 != "bin")
		printf("Login %s has a user id of 1.\n", $1);
        if ($3 < 0)
                printf("Login %s has a negative user id.\n", $1);
        if ($4 < 0)
                printf("Login %s has a negative group id.\n", $1);
	if ($4 == 0 && $1 != "root")
		printf("Login %s has a group id of 0.\n", $1);
	if ($4 == 1 && $1 != "bin")
		printf("Login %s has a group id of 1.\n", $1);
}' < $PW > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking the $PW file:\n"
        /usr/bin/cat "$OUT"
fi
/usr/bin/awk -F: '{ print $1 }' $PW | /usr/bin/sort | /usr/bin/uniq -d > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\n$PW has duplicate user names.\n"
        /usr/bin/column "$OUT"
fi
/usr/bin/awk -F: '{ print $1 " " $3 }' $PW | /usr/bin/sort -n +1 | /usr/bin/tee $TMP1 |
/usr/bin/uniq -d -f 1 | /usr/bin/awk '{ print $2 }' > $TMP2
if [ -s "$TMP2" ] ; then
        /bin/echo -e "\n$PW has duplicate user ids:"
        while read uid; do
                grep -w $uid $TMP1
        done < $TMP2 | /usr/bin/column
fi
/bin/cp -pf $PW $PW.backup
#
# /etc/shadow check
#
PW="/etc/shadow"
/usr/bin/awk -F: '{
        if ($0 ~ /^[ 	]*$/) {
                printf("Line %d is a blank line.\n", NR);
                next;
        }
        if (NF != 9)
                printf("Line %d has the wrong number of fields.\n", NR);
        if ($1 ~ /^[+-]$/)
                next;
        if ($1 == "")
                printf("Line %d has an empty login field.\n", NR);
        else if ($1 !~ /^[A-Za-z0-9][A-Za-z0-9_-]*$/)
                printf("Login %s has non-alphanumeric characters.\n", $1);
        if (length($1) > 8)
                printf("Login %s has more than 8 characters.\n", $1);
        if ($2 == "")
                printf("Login %s has no password.\n", $1);
	if ($2 != "" && length($2) != 13 && length($2) != 34 &&
	    length($2) != 1 && $2 !~ /^\$[0-9a-f]+\$/)
		printf("Login %s has an unsual password field length\n", $1);
}' < $PW > "$OUT"
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking the $PW file:\n"
        /usr/bin/cat "$OUT"
fi
/usr/bin/awk -F: '{ print $1 }' $PW | /usr/bin/sort | /usr/bin/uniq -d > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\n$PW has duplicate user names.\n"
        /usr/bin/column "$OUT"
fi
/bin/cp -fp "$PW" "$PW.backup"
#
# /etc/group checking
#
GRP=/etc/group
/usr/bin/awk -F: '{
        if ($0 ~ /^[	 ]*$/) {
                printf("Line %d is a blank line.\n", NR);
                next;
        }
        if ($1 ~ /^[+-]$/)
                next;
        if (NF != 4)
                printf("Line %d has the wrong number of fields.\n", NR);
        if ($1 !~ /^[A-za-z0-9][A-za-z0-9_-]*$/)
                printf("Group %s has non-alphanumeric characters.\n", $1);
        if (length($1) > 8)
                printf("Group %s has more than 8 characters.\n", $1);
        if ($3 !~ /[0-9]*/)
                printf("Login %s has a negative group id.\n", $1);
        if (length($4) > 0 && $3 < 3)
		printf("Group %s(%s) has got the following members: %s\n", $1, $3, $4);
}' < $GRP > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking the $GRP file:\n"
        /usr/bin/cat "$OUT"
fi
/usr/bin/awk -F: '{ print $1 }' $GRP | /usr/bin/sort | /usr/bin/uniq -d > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\n$GRP has duplicate group names.\n"
        /usr/bin/column "$OUT"
fi
#
# checking root's login scrips for secure path and umask
#
> $OUT
> $TMP1
> $TMP2
rhome=/root
umaskset=no
list="/etc/csh.cshrc /etc/csh.login"
for i in $list ; do
        if [ -s "$i" ] ; then
                if /usr/bin/egrep umask $i > /dev/null ; then
                        umaskset=yes
                fi
                /usr/bin/egrep umask $i |
                /usr/bin/awk '$2 % 100 < 20 \
                        { print "Root umask is group writeable" }
                     $2 % 10 < 2 \
                        { print "Root umask is other writeable" }' >> $OUT
                SAVE_PATH=$PATH
                unset PATH 2> /dev/null || PATH="" # redhat ... 
                /bin/csh -f -s << end-of-csh > /dev/null 2>&1
                        test -f "$i" && (	# still a race
                            source $i
                            /bin/ls -ldcbg \$path > $TMP1
			)
end-of-csh
                PATH=$SAVE_PATH
                /usr/bin/awk '{
                        if ($9 ~ /^\.$/) {
                                print "The root path includes .";
                                next;
                        }
                     }
                     $1 ~ /^d....w/ \
        { print "Root path directory " $9 " is group writeable." } \
                     $1 ~ /^d.......w/ \
        { print "Root path directory " $9 " is other writeable." }' \
                < $TMP1 >> $TMP2
        fi
done
if [ $umaskset = "no" -o -s "$TMP2" ] ; then
	/usr/bin/sort -u $TMP2 > $OUT
        /usr/bin/printf "\nChecking root csh paths, umask values:\n$list\n"
        if [ -s "$OUT" ] ; then
                /usr/bin/cat "$OUT"
        fi
        if [ $umaskset = "no" ] ; then
                /usr/bin/printf "\nRoot csh startup files do not set the umask.\n"
        fi
fi
> $OUT
> $TMP1
> $TMP2
rhome=/root
umaskset=no
list="/etc/profile ${rhome}/.profile ${rhome}/.bashrc ${rhome}/.bash_login"
for i in $list; do
        if [ -s "$i" ] ; then
                if /usr/bin/egrep umask $i > /dev/null ; then
                        umaskset=yes
                fi
                /usr/bin/egrep umask $i |
                /usr/bin/awk '$2 % 100 < 20 \
                        { print "Root umask is group writeable" } \
                     $2 % 10 < 2 \
                        { print "Root umask is other writeable" }' >> $OUT
                SAVE_PATH=$PATH
                unset PATH 2> /dev/null || PATH="" # redhat again ...
                /bin/sh << end-of-sh > /dev/null 2>&1
                        /usr/bin/file "$i" | /usr/bin/grep -qw text && . $i
                        list=\`/bin/echo \$PATH | /usr/bin/sed -e 's/:/ /g'\`
			/bin/ls -ldgbT \$list > $TMP1
end-of-sh
                PATH=$SAVE_PATH
                /usr/bin/awk '{
                        if ($9 ~ /^\.$/) {
                                print "The root path includes .";
                                next;
                        }
                     }
                     $1 ~ /^d....w/ \
        { print "Root path directory " $9 " is group writeable." } \
                     $1 ~ /^d.......w/ \
        { print "Root path directory " $9 " is other writeable." }' \
                < $TMP1 >> $TMP2

        fi
done
if [ $umaskset = "no" -o -s "$TMP2" ] ; then
	/usr/bin/sort -u $TMP2 > $OUT
        /usr/bin/printf "\nChecking root sh paths, umask values:\n$list\n"
        if [ -s "$OUT" ] ; then
                /usr/bin/cat "$OUT"
        fi
        if [ $umaskset = "no" ] ; then
                /usr/bin/printf "\nRoot sh startup files do not set the umask.\n"
        fi
fi
#
# Misc. file checks
#
# root/uucp/bin/daemon etc. should be in /etc/ftpusers.
if [ -s /etc/ftpusers ]; then
	> $OUT
	/usr/bin/grep -q '^root$' /etc/ftpusers || /bin/echo root >> $OUT
	/usr/bin/grep -q '^bin$' /etc/ftpusers || /bin/echo bin >> $OUT
        /usr/bin/grep -q '^uucp$' /etc/ftpusers || /bin/echo uucp >> $OUT
        /usr/bin/grep -q '^daemon$' /etc/ftpusers || /bin/echo daemon >> $OUT
        /usr/bin/grep -q '^nobody$' /etc/ftpusers || /bin/echo nobody >> $OUT
        /usr/bin/grep -q '^lp$' /etc/ftpusers || /bin/echo lp >> $OUT
        /usr/bin/grep -q '^man$' /etc/ftpusers || /bin/echo man >> $OUT
	if [ -s "$OUT" ] ; then
	    /usr/bin/printf "\nThe following system accounts are missing in /etc/ftpusers:\n"
	    /usr/bin/cat "$OUT"
	fi
fi
# executables should not be in the /etc/mail/aliases file.
if [ -s /etc/aliases ]; then
    /usr/bin/grep -v '^#' /etc/mail/aliases | /usr/bin/grep '|' > $OUT
    if [ -s "$OUT" ] ; then
            /usr/bin/printf "\nThe following programs are executed in your mail via /etc/mail/aliases (bad!):\n"
            /usr/bin/cat "$OUT"
    fi
fi
# Files that should not have + signs.
list="/etc/hosts.equiv /etc/shosts.equiv /etc/hosts.lpd"
for f in $list ; do
        if [ -s "$f" ] ; then
                /usr/bin/awk '{
                        if ($0 ~ /^\+@.*$/)
                                next;
                        if ($0 ~ /^\+.*$/)
                                printf("\nPlus sign in the file %s\n", FILENAME);
                }' $f
        fi
done
# .rhosts check
/usr/bin/awk -F: '{ print $1 " " $6 }' /etc/passwd |
while read uid homedir; do
        for j in .rhosts .shosts; do
                if [ -s ${homedir}/$j ] ; then
                        rhost=`/bin/ls -lcdbg ${homedir}/$j| /usr/bin/sed 's/[%\]/_/g'`
			/usr/bin/printf "$uid: $rhost\n"
			test -f "$j" && { # still a race, however ...
			    if /usr/bin/egrep + ${homedir}/$j > /dev/null ; then
				/usr/bin/printf "\t(has got a plus (+) sign!)\n"
			    fi
			}
                fi
        done
done > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking for users with .rhosts/.shosts files.\n"
        /usr/bin/cat "$OUT"
fi
# Check home directories.  Directories should not be owned by someone else
# or writeable.
/usr/bin/awk -F: '/^[^+-]/ { print $1 " " $6 }' /etc/passwd | \
while read uid homedir; do
        if [ -d ${homedir}/ ] ; then
                file=`/bin/ls -ldbg ${homedir} | /usr/bin/sed 's/[%\]/_/g'`
                /usr/bin/printf "$uid $file\n"
        fi
done |
/usr/bin/awk '$1 != $4 && $4 != "root" \
        { print "user " $1 " : home directory is owned by " $4 }
     $2 ~ /^-....w/ \
        { print "user " $1 " : home directory is group writeable" }
     $2 ~ /^-.......w/ \
        { print "user " $1 " : home directory is other writeable" }' > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking home directories.\n"
        /usr/bin/sort -u "$OUT"
fi
# Files that should not be owned by someone else or readable.
#list=".netrc .rhosts .shosts .Xauthority .pgp/secring.pgp .ssh/identity .ssh/random_seed"

####
# This section was originally commented by Marc.
#
#awk -F: '/^[^+-]/ { print $1 " " $6 }' /etc/passwd | \
#while read uid homedir; do
#        for f in $list ; do
#                file=${homedir}/${f}
#                if [ -f "$file" ] ; then
#                        printf "$uid $f `ls -ldcbg $file`\n"
#                fi
#        done
#done |
#awk '$1 != $5 && $5 != "root" \
#        { print "user " $1 " " $2 " : file is owned by " $5 }
#     $3 ~ /^-...r/ \
#        { print "user " $1 " " $2 " : file is group readable" }
#     $3 ~ /^-......r/ \
#        { print "user " $1 " " $2 " : file is other readable" }
#     $3 ~ /^-....w/ \
#        { print "user " $1 " " $2 " : file is group writeable" }
#     $3 ~ /^-.......w/ \
#        { print "user " $1 " " $2 " : file is other writeable" }' > $OUT
####

# Files that should not be owned by someone else or writeable.
list=".bashrc .bash_profile .bash_login .bash_logout .cshrc .emacs .exrc \
.forward .klogin .login .logout .profile .tcshrc .fvwmrc .inputrc .kshrc \
.nexrc .screenrc .ssh .ssh/config .ssh/authorized_keys .ssh/environment \
.ssh/known_hosts .ssh/rc .twmrc .xsession .xinitrc .Xdefaults .rhosts \
.shosts .Xauthority .pgp/secring.pgp .ssh/identity .ssh/random_seed \
.pgp/randseed.bin .netrc .exrc .vimrc .viminfo"
/usr/bin/awk -F: '/^[^+-]/ { print $1 " " $6 }' /etc/passwd | \
while read uid homedir; do
        for f in $list ; do
                file=${homedir}/${f}
                if [ -f "$file" ] ; then
                        /usr/bin/printf "$uid $f `ls -ldcbg $file|sed 's/[%\]/_/g'`\n"
                fi
        done
done |
/usr/bin/awk '$1 != $5 && $5 != "root" \
        { print "user " $1 " " $2 " : file is owned by " $5 }
     $3 ~ /^-....w/ \
        { print "user " $1 " " $2 " : file is group writeable" }
     $3 ~ /^-.......w/ \
        { print "user " $1 " " $2 " : file is other writeable" }' >> $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking dot files.\n"
        /usr/bin/sort -u "$OUT"
fi
# Mailboxes should be owned by user and unreadable.
/bin/ls -cl /var/spool/mail | /usr/bin/sed 1d | \
/usr/bin/awk '$3 != $9 \
        { print "user " $9 " mailbox is owned by " $3 }
     $1 != "-rw-------" \
        { print "user " $9 " mailbox is " $1 ", group " $4 }' > $OUT
if [ -s "$OUT" ] ; then
        /usr/bin/printf "\nChecking mailbox ownership.\n"
        /usr/bin/sort -u "$OUT"
fi
# File systems should not be globally exported.
if [ -s /etc/exports ] ; then
        /usr/bin/awk '{
                if (($1 ~ /^#/) || ($1 ~ /^$/))
                        next;
                readonly = 0;
                for (i = 2; i <= NF; ++i) {
                        if ($i ~ /^-ro$/)
                                readonly = 1;
                        else if ($i !~ /^-/)
                                next;
                }
                if (readonly)
                        print "File system " $1 " globally exported, read-only.";
		else
                        print "File system " $1 " globally exported, read-write.";
        }' < /etc/exports > $OUT
        if [ -s "$OUT" ] ; then
                /usr/bin/printf "\nChecking for globally exported file systems.\n"
                /usr/bin/cat "$OUT"
        fi
fi
# promisc check
> $OUT
/sbin/ifconfig | /usr/bin/grep PROMISC 1> /dev/null && /sbin/ifconfig | \
	/usr/bin/grep -C PROMISC | /usr/bin/grep -v '   [RT]X p'> $OUT
if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nChecking devices for promiscious mode.\n"
    /usr/bin/cat "$OUT"
fi
# list loaded modules
> $OUT
test -e /proc/modules && { /sbin/lsmod 2> /dev/null | /usr/bin/grep -v '^Module .* Used by$' | /usr/bin/awk '{print$1}' | /usr/bin/sort > $OUT
 if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nThe following loadable kernel modules are currently installed:\n"
    /usr/bin/cat "$OUT"
 fi
}
# nfs mounts with missing nosuid
> $OUT
/bin/mount | /usr/bin/grep -v nosuid | /usr/bin/grep ' nfs ' | /usr/bin/sort > $OUT
if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nThe following NFS mounts haven't got the nosuid option set:\n"
    /usr/bin/cat "$OUT"
fi

## display programs with bound sockets
> $OUT
/bin/netstat -ape | /usr/bin/egrep '[udp|tcp|raw].*LISTEN' > $OUT
if [ -s "$OUT" ]; then
    /usr/bin/printf "\nThe following programs have got bound sockets:\n"
    /usr/bin/cat "$OUT"
fi

####
#
# Cleaning up
#
/bin/rm -rf "$TMPDIR"
exit 0
# END OF SCRIPT
