#!/bin/sh
#
# $Id: security-weekly.sh,v 1.8 2001/12/16 15:49:39 dentonj Exp $
#
######################################
#
# Seccheck for Slackware Linux
#
# The program was modified for SAStk by Jeffrey Denton <dentonj@sastk.org>.  
# It was originally written by Marc Heuse <marc@suse.de> for SuSE.  
#
######################################

####
#
# Slackware weekly security checks 
#
####
#
# TODO /etc /home /home/.* permissions
#

umask 077
PATH=/sbin:/usr/sbin:/bin:/usr/bin
SEC_BIN="/usr/local/sbin/seccheck"
SEC_VAR="/var/log/sastk/seccheck"
SEC_DATA="$SEC_VAR/data"
TMPDIR=`/usr/bin/mktemp -d /root/.security.XXXXXX 2> /dev/null` || {
    TMPDIR="/root/.security-weekly.sh.$$"
    /bin/mkdir "$TMPDIR" || exit 1
}
OUT="$TMPDIR/security.out"
TMP1="$TMPDIR/security.tmp1"
TMP2="$TMPDIR/security.tmp2"

if [ ! -d "$SEC_VAR" ] ; then
    /bin/mkdir "$SEC_VAR" || exit 1
fi
if [ ! -d "$SEC_DATA" ] ; then
    /bin/mkdir "$SEC_DATA" || exit 1
fi

trap 'rm -rf $TMPDIR; exit 1' 0 1 2 3 13 15

# init
for i in "$SEC_DATA/sbit" "$SEC_DATA/write" "$SEC_DATA/devices" "$SEC_DATA/write-bin"; do
    if [ ! -e "$i" ] ; then
        /bin/touch "$i"
    fi
done

# get the ext2 and reiserfs mount points
MNT=`/bin/mount | /usr/bin/awk '/ ext2 | reiserfs / {print$3}'| /usr/bin/xargs -s 4000 echo`

test -z "$MAILER" && test -x "/usr/sbin/sendmail" && MAILER="/usr/sbin/sendmail"
test -z "$MAILER" && test -x "/usr/bin/mailx" && MAILER="/usr/bin/mailx"
test -z "$MAILER" && test -x "/usr/lib/sendmail" && MAILER="/usr/lib/sendmail"
test -z "$MAILER" && MAILER="mail"

####
# Commented until SAStk installs John.
#
## password check
#if [ -x /usr/sbin/john -a -x /usr/sbin/unshadow ]; then
#    echo > $SEC_VAR/dict
#    cat /usr/dict/* /var/lib/john/password.lst 2> /dev/null | sort | uniq >> $SEC_VAR/dict
#    unshadow /etc/passwd /etc/shadow > $SEC_VAR/passwd
#    nice -n 1 john -single "$SEC_VAR/passwd" 1> /dev/null 2>&1
#    nice -n 1 john -rules -w:$SEC_VAR/dict "$SEC_VAR/passwd" 1> /dev/null 2>&1
#    john -show "$SEC_VAR/passwd" | sed -n 's/:.*//p' > "$OUT"
#    if [ -s "$OUT" ] ; then
#        for i in `cat "$OUT"`; do
#             $MAILER "$i" << _EOF_
#Subject: Please change your Password
#
#Your password for account "$i" is insecure.
#Please change it as soon as possible.
#
#Yours,
#        Password Checking Robot
#
#_EOF_
#        done
#        printf "\nThe following user accounts have guessable passwords:\n"
#	cat "$OUT"
#    fi
#else
#    echo -e "\nPassword security checking not possible, package "john" not installed."
#fi
#rm -f $SEC_VAR/passwd
####

# neverlogin check
$SEC_BIN/checkneverlogin > "$OUT"
if [ -s "$OUT" ] ; then
	/usr/bin/printf "\nPlease check and perhaps disable the following unused accounts:\n"
	/usr/bin/cat "$OUT"
fi

# suid/sgid check
( /usr/bin/nice -n 1 /usr/bin/find $MNT \( -perm -04000 -o -perm -02000 \) -mount -type f | /usr/bin/sort | /usr/bin/xargs ls -cdl --full-time -- > "$SEC_DATA/sbit.new" ) 2> /dev/null
/usr/bin/diff -uw "$SEC_DATA/sbit" "$SEC_DATA/sbit.new" | \
	/usr/bin/egrep -v '^\+\+\+ |^--- |^$|^@@' | /usr/bin/sed 's/^[+-]/& /' > "$OUT"
if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nThe following files are suid/sgid:\n"
    /usr/bin/cat "$OUT"
    /bin/mv "$SEC_DATA/sbit.new" "$SEC_DATA/sbit"
fi
/bin/rm -f "$SEC_DATA/sbit.new"

# writeable executable check
( /usr/bin/nice -n 1 /usr/bin/find $MNT \( -perm -30 -o -perm -3 \) -mount -type f | /usr/bin/sort | /usr/bin/xargs ls -cdl --full-time -- > "$SEC_DATA/write-bin.new" ) 2> /dev/null
/usr/bin/diff -uw "$SEC_DATA/write-bin" "$SEC_DATA/write-bin.new" | \
	/usr/bin/egrep -v '^\+\+\+ |^--- |^$|^@@' | /usr/bin/sed 's/^[+-]/& /' > "$OUT"
if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nThe following program executables are group/world writeable:\n"
    /usr/bin/cat "$OUT"
    /bin/mv "$SEC_DATA/write-bin.new" "$SEC_DATA/write-bin"
fi
/bin/rm -f "$SEC_DATA/write-bin.new"

# world writable check
( /usr/bin/nice -n 1 /usr/bin/find $MNT -perm -2 \( -type f -o -type d \) -not -perm -01000 -mount | /usr/bin/sort > "$SEC_DATA/write.new" ) 2> /dev/null
/usr/bin/diff -uw "$SEC_DATA/write" "$SEC_DATA/write.new" | \
	/usr/bin/egrep -v '^\+\+\+ |^--- |^$|^@@' | /usr/bin/sed 's/^[+-]/& /' > "$OUT"
if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nThe following files/directories are world writeable and not sticky:\n"
    /usr/bin/cat "$OUT"
    /bin/mv "$SEC_DATA/write.new" "$SEC_DATA/write"
fi
/bin/rm -f "$SEC_DATA/write.new"

# nouser nogroup check
( /usr/bin/nice -n 1 /usr/bin/find $MNT -nouser -o -nogroup | /usr/bin/sort > "$SEC_DATA/nouser.new" ) 2> /dev/null
/usr/bin/diff -uw "$SEC_DATA/nouser" "$SEC_DATA/nouser.new" | \
	/usr/bin/egrep -v '^\+\+\+ |^--- |^$|^@@' | /usr/bin/sed 's/^[+-]/& /' > "$OUT"
if [ -s "$OUT" ]; then
	/usr/bin/printf "\nThe following files/directories DO NOT belong to any user or group:\n"
	/usr/bin/cat "$OUT"
	/bin/mv "$SEC_DATA/nouser.new" "$SEC_DATA/nouser"
fi
/bin/rm -f "$SEC_DATA/nouser.new"

# regular files in /dev check
( /usr/bin/nice -n 1 /usr/bin/find /dev -type f | /usr/bin/sort > "$SEC_DATA/reg_dev.new" ) 2> /dev/null
/usr/bin/diff -uw "$SEC_DATA/reg_dev" "$SEC_DATA/reg_dev.new" | \
	/usr/bin/egrep -v '^\+\+\+ |^--- |^$|^@@' | /usr/bin/sed 's/^[+-]/& /' > "$OUT"
if [ -s "$OUT" ]; then
	/usr/bin/printf "\nThe following regular files were found in /dev, make sure they belong there:\n"
	/usr/bin/cat "$OUT"
	/bin/mv "$SEC_DATA/reg_dev.new" "$SEC_DATA/reg_dev"
fi
/bin/rm -f "$SEC_DATA/reg_dev.new"

# device check
( /usr/bin/nice -n 1 /usr/bin/find $MNT -type c -or -type b -mount | /usr/bin/xargs ls -cdl -- | \
	/usr/bin/awk '{print $1 " \t" $3 " \t" $4 " \t" $5 " \t" $6 " \t" $10}' | /usr/bin/sort +5 \
	> "$SEC_DATA/devices.new" ) 2> /dev/null
/usr/bin/diff -uw "$SEC_DATA/devices" "$SEC_DATA/devices.new" | \
	/usr/bin/egrep -v '^\+\+\+ |^--- |^$|^@@' | /usr/bin/sed 's/^[+-]/& /' > "$OUT"
if [ -s "$OUT" ] ; then
    /usr/bin/printf "\nThe following devices were added:\n"
    /usr/bin/cat "$OUT"
    /bin/mv "$SEC_DATA/devices.new" "$SEC_DATA/devices"
fi
/bin/rm -f "$SEC_DATA/devices.new"

####
#
# Cleaning up
#
/bin/rm -rf "$TMPDIR"
exit 0
# END OF SCRIPT
